@@ -81,6 +81,7 @@ __docformat__ = 'reStructuredText'
 searchUrl = "http://ilthermo.boulder.nist.gov/ILT2/ilsearch"
 dataUrl = "http://ilthermo.boulder.nist.gov/ILT2/ilset"
 
+prop2key = {}
 
 def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
 
@@ -146,15 +147,15 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
         prp = prp
     )
 
-    r1 = requests.get(searchUrl, params=params)
-    resDict = r1.json()
+    r = requests.get(searchUrl, params=params)
+    resDict = r.json()
     if len(resDict['errors']) > 0:
         e = " *** ".join(resDict['errors'])
         #JOAO
         print("len(resDict['errors']) > 0")
         #JOAO
         raise queryError(e)
-    return result(resDict)
+    return result(resDict), prop2key
 
 
 class result(object):
